@@ -29,21 +29,31 @@
 #include <iomanip>
 
 
-namespace HepMC3 
+namespace HepMC3
 {
 class ReaderLHEF : public Reader
 {
 public:
+    /// The ctor to read from stream
+    ReaderLHEF(std::istream &);
+private:
+    void init();                       ///< Init helper
+public:
+    /** @brief Constructor */
     ReaderLHEF(const std::string& filename);
+    /** @brief Reading event */
     bool read_event(GenEvent& ev);
+    /** @brief Close */
     void close();
+    /** @brief State */
     bool failed();
+    /** @brief Destructor */
     ~ReaderLHEF() ;
 private:
-    LHEF::Reader* m_reader;
-    shared_ptr<HEPRUPAttribute> m_hepr;
-    int m_neve;
-    bool m_failed;
+    LHEF::Reader* m_reader;            ///< The actual reader
+    shared_ptr<HEPRUPAttribute> m_hepr; ///< Holder of attributes
+    int m_neve;                         ///< Event counter
+    bool m_failed;                      ///< State of reader
 };
 }
 #endif
\ No newline at end of file
