@@ -10,9 +10,9 @@
 #include "HepMC3/Relatives.h"
 
 namespace HepMC3 {
-  const Parents     Relatives::PARENTS;
-  const Children    Relatives::CHILDREN;
-  const Ancestors   Relatives::ANCESTORS;
-  const Descendants Relatives::DESCENDANTS;
+const Parents     Relatives::PARENTS;
+const Children    Relatives::CHILDREN;
+thread_local const Ancestors   Relatives::ANCESTORS;
+thread_local const Descendants Relatives::DESCENDANTS;
 }
 
